@@ -1,7 +1,10 @@
+#' Internal functions for IS/IV computation
+#'
+#' Internal helper functions used by the nparACT package.
+#'
+#' @keywords internal
+NULL
 nparACT_ISIVfunctions <- list(
-
-  #' @description Functions calculating IS and IV values.
-
   nparACT_ISIV = function(data_hrs, bin_hr){
     n <- nrow(data_hrs)
     p <- 1440/bin_hr
