@@ -1,7 +1,10 @@
+#' Internal functions for RA computation
+#'
+#' Internal helper functions used by the nparACT package.
+#'
+#' @keywords internal
+NULL
 nparACT_RAfunctions <- list(
-
-  #' @description Functions calculating L5 and M10 values.
-
   nparACT_L5M10 = function(data, minaverage, a, SR){
     ## ---- L5 values
     L5_matrix <- matrix(NA, 1440)
