@@ -1,7 +1,11 @@
+#' Internal functions for data preparation
+#'
+#' Internal helper functions used by the nparACT package.
+#'
+#' @keywords internal
+NULL
 nparACT_auxfunctions1 <- list(
 
-  #' @description Auxiliary function preparing the data for the analyses.
-
   nparACT_data_hrs = function(data, a, m){
     data_hrs <- matrix(NA, nrow = a/m)
     for (i in 1:(a/m)){
@@ -12,8 +16,6 @@ nparACT_auxfunctions1 <- list(
     return(data_hrs)
   },
 
-  #' @description Auxiliary function preparing the data for the analyses.
-
   nparACT_data_min = function(b, SR, data){
     data_min <- matrix(NA, b)
     for (d in 1:b){
@@ -23,7 +25,6 @@ nparACT_auxfunctions1 <- list(
     return(data_min)
   },
 
-  #' @description Auxiliary function preparing the data for the analyses.
 
   nparACT_filt = function(data, a, cutoff){
     for (k in 1:a){
@@ -33,8 +34,6 @@ nparACT_auxfunctions1 <- list(
     }
   },
 
-  #' @description Auxiliary function creating minute-wise averages across 24 hours.
-
   nparACT_minaverage = function(b, data_min){
     ## ---- Minutewise averages across 24hrs -> 1440 values
     c <- ceiling(b/1440)
@@ -48,8 +47,6 @@ nparACT_auxfunctions1 <- list(
   },
 
 ## ---- Hourly averages
-  #' @description Auxiliary function creating hourly averages.
-
   nparACT_hraverage_GA_loop = function(minaverage, data, a , SR){
     hraverage <- matrix(NA)
     for (i in 1:24){
